@@ -106,7 +106,7 @@ KCRASH_EXPORT HandlerType crashHandler();
  * is installed to ensure the save function will be called.
  * @param saveFunction the handler to install
  */
-KCRASH_EXPORT void setEmergencySaveFunction(HandlerType saveFunction = 0);
+KCRASH_EXPORT void setEmergencySaveFunction(HandlerType saveFunction = nullptr);
 
 /**
  * Returns the currently set emergency save function.
@@ -154,6 +154,14 @@ KCRASH_EXPORT void setDrKonqiEnabled(bool enabled);
  * @since 4.5
  */
 KCRASH_EXPORT bool isDrKonqiEnabled();
+
+/**
+ * Allows providing information to be included in the bug report.
+ *
+ * @since 5.69
+ */
+KCRASH_EXPORT void setErrorMessage(const QString &message);
+
 }
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KCrash::CrashFlags)
